#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// </summary>
    [Description("Leader")]
    public class Leader : Indicator
    {
        #region Variables
            private int fast = 12;
            private int slow = 26;
			private DataSeries mySeries1;
			private DataSeries mySeries2;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Red), PlotStyle.Line, "Leader"));
            CalculateOnBarClose	= true;
            Overlay				= false;
            PriceTypeSupported	= false;
			
			mySeries1 = new DataSeries(this);
			mySeries2 = new DataSeries(this);
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			mySeries1.Set(Close[0] - EMA(Fast)[0]);
			mySeries2.Set(Close[0] - EMA(Slow)[0]);
            Value.Set((EMA(Fast)[0] + EMA(mySeries1, Fast)[0]) - (EMA(Slow)[0] + EMA(mySeries2, Slow)[0]));
        }

        #region Properties
        [Description("Fast period")]
        [Category("Parameters")]
        public int Fast
        {
            get { return fast; }
            set { fast = Math.Max(1, value); }
        }

        [Description("Slow period")]
        [Category("Parameters")]
        public int Slow
        {
            get { return slow; }
            set { slow = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private Leader[] cacheLeader = null;

        private static Leader checkLeader = new Leader();

        /// <summary>
        /// Leader
        /// </summary>
        /// <returns></returns>
        public Leader Leader(int fast, int slow)
        {
            return Leader(Input, fast, slow);
        }

        /// <summary>
        /// Leader
        /// </summary>
        /// <returns></returns>
        public Leader Leader(Data.IDataSeries input, int fast, int slow)
        {
            checkLeader.Fast = fast;
            fast = checkLeader.Fast;
            checkLeader.Slow = slow;
            slow = checkLeader.Slow;

            if (cacheLeader != null)
                for (int idx = 0; idx < cacheLeader.Length; idx++)
                    if (cacheLeader[idx].Fast == fast && cacheLeader[idx].Slow == slow && cacheLeader[idx].EqualsInput(input))
                        return cacheLeader[idx];

            Leader indicator = new Leader();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.Fast = fast;
            indicator.Slow = slow;
            indicator.SetUp();

            Leader[] tmp = new Leader[cacheLeader == null ? 1 : cacheLeader.Length + 1];
            if (cacheLeader != null)
                cacheLeader.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheLeader = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Leader
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.Leader Leader(int fast, int slow)
        {
            return _indicator.Leader(Input, fast, slow);
        }

        /// <summary>
        /// Leader
        /// </summary>
        /// <returns></returns>
        public Indicator.Leader Leader(Data.IDataSeries input, int fast, int slow)
        {
            return _indicator.Leader(input, fast, slow);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Leader
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.Leader Leader(int fast, int slow)
        {
            return _indicator.Leader(Input, fast, slow);
        }

        /// <summary>
        /// Leader
        /// </summary>
        /// <returns></returns>
        public Indicator.Leader Leader(Data.IDataSeries input, int fast, int slow)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.Leader(input, fast, slow);
        }

    }
}
#endregion
